==> aspectran-core-5.1.0-sources.jar: com/aspectran/core/activity/ActivityTerminatedException.java <==
/*
 * Copyright (c) 2008-2018 The Aspectran Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.aspectran.core.activity;

/**
 * Raised if an activity is terminated during processing.
 */
public class ActivityTerminatedException extends ActivityException {

    /** @serial */
    private static final long serialVersionUID = 6615572357964634821L;

    /**
     * Simple constructor.
     */
    public ActivityTerminatedException() {
        super();
    }

    /**
     * Constructor to create exception with a message.
     *
     * @param msg a message to associate with the exception
     */
    public ActivityTerminatedException(String msg) {
        super(msg);
    }

    /**
     * Constructor to create exception to wrap another exception.
     *
     * @param cause the real cause of the exception
     */
    public ActivityTerminatedException(Throwable cause) {
        super(cause);
    }

    /**
     * Constructor to create exception to wrap another exception and pass a message.
     *
     * @param msg the message
     * @param cause the real cause of the exception
     */
    public ActivityTerminatedException(String msg, Throwable cause) {
        super(msg, cause);
    }

}

==> aspectran-core-6.13.3-sources.jar: com/aspectran/core/activity/ActivityTerminatedException.java <==
/*
 * Copyright (c) 2008-2021 The Aspectran Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.aspectran.core.activity;

/**
 * Checked exception thrown when activity is terminated while preparing or performing.
 */
public class ActivityTerminatedException extends ActivityPerformException {

    /** @serial */
    private static final long serialVersionUID = 6615572357964634821L;

    /**
     * Simple constructor.
     */
    public ActivityTerminatedException() {
        super();
    }

    /**
     * Constructor to create exception with a message.
     *
     * @param msg a message to associate with the exception
     */
    public ActivityTerminatedException(String msg) {
        super(msg);
    }

    /**
     * Constructor to create exception to wrap another exception.
     *
     * @param cause the real cause of the exception
     */
    public ActivityTerminatedException(Throwable cause) {
        super(cause);
    }

    /**
     * Constructor to create exception to wrap another exception and pass a message.
     *
     * @param msg the message
     * @param cause the real cause of the exception
     */
    public ActivityTerminatedException(String msg, Throwable cause) {
        super(msg, cause);
    }

}
